pub struct GuardrailContract {
pub addr: Addr,
pub init: InstantiateMsg,
}Fields
addr: Addrinit: InstantiateMsgTrait Implementations
Sourceimpl Clone for GuardrailContract
impl Clone for GuardrailContract
Sourcefn clone(&self) -> GuardrailContract
fn clone(&self) -> GuardrailContract
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GuardrailContract
impl Debug for GuardrailContract
Sourceimpl<'de> Deserialize<'de> for GuardrailContract
impl<'de> Deserialize<'de> for GuardrailContract
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for GuardrailContract
impl PartialEq for GuardrailContract
Sourceimpl Serialize for GuardrailContract
impl Serialize for GuardrailContract
Sourceimpl TestingContract<InstantiateMsg, ExecuteMsg, QueryMsg> for GuardrailContract
impl TestingContract<InstantiateMsg, ExecuteMsg, QueryMsg> for GuardrailContract
fn wrapper() -> Box<dyn Contract<Empty>>
fn default_init(app: &mut App, _env: &Env) -> InstantiateMsg
fn new(app: &mut App, env: &Env, msg: Option<InstantiateMsg>) -> Self
fn addr(&self) -> &Addr
fn store_code(app: &mut App) -> u64
fn instantiate(app: &mut App, code_id: u64, label: &str, msg: &IM) -> Addr
Sourcefn set_contract_addr(app: &mut App, label: &str, addr: &Addr)
fn set_contract_addr(app: &mut App, label: &str, addr: &Addr)
Set the contract address in the storage for the given label.
Using the storage system for easy orchestration of contract addresses for testing.
Sourcefn get_contract_addr(app: &App, label: &str) -> Addr
fn get_contract_addr(app: &App, label: &str) -> Addr
Get the contract address in the storage for the given label.
fn execute( &self, app: &mut App, sender: &Addr, msg: &EM, ) -> Result<AppResponse, Error>
fn execute_with_funds( &self, app: &mut App, sender: &Addr, msg: &EM, funds: Vec<Coin>, ) -> Result<AppResponse, Error>
fn query<T>(&self, app: &App, msg: &QM) -> Result<T, StdError>where
T: DeserializeOwned,
fn migrate( &self, app: &mut App, sender: &Addr, msg: &MM, ) -> Result<AppResponse, Error>
impl StructuralPartialEq for GuardrailContract